AdvancedFieldSelector class

A single selector statement in an advanced event selector.

Constructors

AdvancedFieldSelector({required String field, List<String>? endsWith, List<String>? equals, List<String>? notEndsWith, List<String>? notEquals, List<String>? notStartsWith, List<String>? startsWith})
AdvancedFieldSelector.fromJson(Map<String, dynamic> json)
factory

Properties

endsWith → List<String>?
An operator that includes events that match the last few characters of the event record field specified as the value of Field.
final
equals → List<String>?
An operator that includes events that match the exact value of the event record field specified as the value of Field. This is the only valid operator that you can use with the readOnly, eventCategory, and resources.type fields.
final
field → String
A field in an event record on which to filter events to be logged. Supported fields include readOnly, eventCategory, eventSource (for management events), eventName, resources.type, and resources.ARN.
final
hashCode → int
The hash code for this object.
no setterinherited
notEndsWith → List<String>?
An operator that excludes events that match the last few characters of the event record field specified as the value of Field.
final
notEquals → List<String>?
An operator that excludes events that match the exact value of the event record field specified as the value of Field.
final
notStartsWith → List<String>?
An operator that excludes events that match the first few characters of the event record field specified as the value of Field.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startsWith → List<String>?
An operator that includes events that match the first few characters of the event record field specified as the value of Field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited