CreateTrailResponse class

Returns the objects or data listed below if successful. Otherwise, returns an error.

Constructors

CreateTrailResponse({String? cloudWatchLogsLogGroupArn, String? cloudWatchLogsRoleArn, bool? includeGlobalServiceEvents, bool? isMultiRegionTrail, bool? isOrganizationTrail, String? kmsKeyId, bool? logFileValidationEnabled, String? name, String? s3BucketName, String? s3KeyPrefix, String? snsTopicARN, String? snsTopicName, String? trailARN})
CreateTrailResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cloudWatchLogsLogGroupArn → String?
Specifies the Amazon Resource Name (ARN) of the log group to which CloudTrail logs will be delivered.
final
cloudWatchLogsRoleArn → String?
Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group.
final
hashCode → int
The hash code for this object.
no setterinherited
includeGlobalServiceEvents → bool?
Specifies whether the trail is publishing events from global services such as IAM to the log files.
final
isMultiRegionTrail → bool?
Specifies whether the trail exists in one region or in all regions.
final
isOrganizationTrail → bool?
Specifies whether the trail is an organization trail.
final
kmsKeyId → String?
Specifies the KMS key ID that encrypts the logs delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the format:
final
logFileValidationEnabled → bool?
Specifies whether log file integrity validation is enabled.
final
name → String?
Specifies the name of the trail.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
Specifies the name of the Amazon S3 bucket designated for publishing log files.
final
s3KeyPrefix → String?
Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files.
final
snsTopicARN → String?
Specifies the ARN of the Amazon SNS topic that CloudTrail uses to send notifications when log files are delivered. The format of a topic ARN is:
final
snsTopicName → String?
This field is no longer in use. Use SnsTopicARN.
final
trailARN → String?
Specifies the ARN of the trail that was created. The format of a trail ARN is:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited