Event class

Contains information about an event that was returned by a lookup request. The result includes a representation of a CloudTrail event.

Constructors

Event({String? accessKeyId, String? cloudTrailEvent, String? eventId, String? eventName, String? eventSource, DateTime? eventTime, String? readOnly, List<Resource>? resources, String? username})
Event.fromJson(Map<String, dynamic> json)
factory

Properties

accessKeyId → String?
The AWS access key ID that was used to sign the request. If the request was made with temporary security credentials, this is the access key ID of the temporary credentials.
final
cloudTrailEvent → String?
A JSON string that contains a representation of the event returned.
final
eventId → String?
The CloudTrail ID of the event returned.
final
eventName → String?
The name of the event returned.
final
eventSource → String?
The AWS service that the request was made to.
final
eventTime → DateTime?
The date and time of the event returned.
final
hashCode → int
The hash code for this object.
no setterinherited
readOnly → String?
Information about whether the event is a write event or a read event.
final
resources → List<Resource>?
A list of resources referenced by the event returned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String?
A user name or role name of the requester that called the API in the event returned.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited