GetEventSelectorsResponse class

Constructors

GetEventSelectorsResponse({List<AdvancedEventSelector>? advancedEventSelectors, List<EventSelector>? eventSelectors, String? trailARN})
GetEventSelectorsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

advancedEventSelectors → List<AdvancedEventSelector>?
The advanced event selectors that are configured for the trail.
final
eventSelectors → List<EventSelector>?
The event selectors that are configured for the trail.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailARN → String?
The specified trail ARN that has the event selectors.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited