GetTrailStatusResponse class

Returns the objects or data listed below if successful. Otherwise, returns an error.

Constructors

GetTrailStatusResponse({bool? isLogging, String? latestCloudWatchLogsDeliveryError, DateTime? latestCloudWatchLogsDeliveryTime, String? latestDeliveryAttemptSucceeded, String? latestDeliveryAttemptTime, String? latestDeliveryError, DateTime? latestDeliveryTime, String? latestDigestDeliveryError, DateTime? latestDigestDeliveryTime, String? latestNotificationAttemptSucceeded, String? latestNotificationAttemptTime, String? latestNotificationError, DateTime? latestNotificationTime, DateTime? startLoggingTime, DateTime? stopLoggingTime, String? timeLoggingStarted, String? timeLoggingStopped})
GetTrailStatusResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLogging → bool?
Whether the CloudTrail is currently logging AWS API calls.
final
latestCloudWatchLogsDeliveryError → String?
Displays any CloudWatch Logs error that CloudTrail encountered when attempting to deliver logs to CloudWatch Logs.
final
latestCloudWatchLogsDeliveryTime → DateTime?
Displays the most recent date and time when CloudTrail delivered logs to CloudWatch Logs.
final
latestDeliveryAttemptSucceeded → String?
This field is no longer in use.
final
latestDeliveryAttemptTime → String?
This field is no longer in use.
final
latestDeliveryError → String?
Displays any Amazon S3 error that CloudTrail encountered when attempting to deliver log files to the designated bucket. For more information see the topic Error Responses in the Amazon S3 API Reference.
final
latestDeliveryTime → DateTime?
Specifies the date and time that CloudTrail last delivered log files to an account's Amazon S3 bucket.
final
latestDigestDeliveryError → String?
Displays any Amazon S3 error that CloudTrail encountered when attempting to deliver a digest file to the designated bucket. For more information see the topic Error Responses in the Amazon S3 API Reference.
final
latestDigestDeliveryTime → DateTime?
Specifies the date and time that CloudTrail last delivered a digest file to an account's Amazon S3 bucket.
final
latestNotificationAttemptSucceeded → String?
This field is no longer in use.
final
latestNotificationAttemptTime → String?
This field is no longer in use.
final
latestNotificationError → String?
Displays any Amazon SNS error that CloudTrail encountered when attempting to send a notification. For more information about Amazon SNS errors, see the Amazon SNS Developer Guide.
final
latestNotificationTime → DateTime?
Specifies the date and time of the most recent Amazon SNS notification that CloudTrail has written a new log file to an account's Amazon S3 bucket.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLoggingTime → DateTime?
Specifies the most recent date and time when CloudTrail started recording API calls for an AWS account.
final
stopLoggingTime → DateTime?
Specifies the most recent date and time when CloudTrail stopped recording API calls for an AWS account.
final
timeLoggingStarted → String?
This field is no longer in use.
final
timeLoggingStopped → String?
This field is no longer in use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited