PublicKey class

Contains information about a returned public key.

Constructors

PublicKey({String? fingerprint, DateTime? validityEndTime, DateTime? validityStartTime, Uint8List? value})
PublicKey.fromJson(Map<String, dynamic> json)
factory

Properties

fingerprint → String?
The fingerprint of the public key.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validityEndTime → DateTime?
The ending time of validity of the public key.
final
validityStartTime → DateTime?
The starting time of validity of the public key.
final
value → Uint8List?
The DER encoded public key value in PKCS#1 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited