Trail class

The settings for a trail.

Constructors

Trail({String? cloudWatchLogsLogGroupArn, String? cloudWatchLogsRoleArn, bool? hasCustomEventSelectors, bool? hasInsightSelectors, String? homeRegion, bool? includeGlobalServiceEvents, bool? isMultiRegionTrail, bool? isOrganizationTrail, String? kmsKeyId, bool? logFileValidationEnabled, String? name, String? s3BucketName, String? s3KeyPrefix, String? snsTopicARN, String? snsTopicName, String? trailARN})
Trail.fromJson(Map<String, dynamic> json)
factory

Properties

cloudWatchLogsLogGroupArn → String?
Specifies an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered.
final
cloudWatchLogsRoleArn → String?
Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group.
final
hasCustomEventSelectors → bool?
Specifies if the trail has custom event selectors.
final
hashCode → int
The hash code for this object.
no setterinherited
hasInsightSelectors → bool?
Specifies whether a trail has insight types specified in an InsightSelector list.
final
homeRegion → String?
The region in which the trail was created.
final
includeGlobalServiceEvents → bool?
Set to True to include AWS API calls from AWS global services such as IAM. Otherwise, False.
final
isMultiRegionTrail → bool?
Specifies whether the trail exists only in one region or exists in all regions.
final
isOrganizationTrail → bool?
Specifies whether the trail is an organization trail.
final
kmsKeyId → String?
Specifies the KMS key ID that encrypts the logs delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the format:
final
logFileValidationEnabled → bool?
Specifies whether log file validation is enabled.
final
name → String?
Name of the trail set by calling CreateTrail. The maximum length is 128 characters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
Name of the Amazon S3 bucket into which CloudTrail delivers your trail files. See Amazon S3 Bucket Naming Requirements.
final
s3KeyPrefix → String?
Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files.The maximum length is 200 characters.
final
snsTopicARN → String?
Specifies the ARN of the Amazon SNS topic that CloudTrail uses to send notifications when log files are delivered. The format of a topic ARN is:
final
snsTopicName → String?
This field is no longer in use. Use SnsTopicARN.
final
trailARN → String?
Specifies the ARN of the trail. The format of a trail ARN is:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited